/**
 * Style loader plugin class.
 */
export default class StyleLoader {
    /** @type {import('@ima/core').Dependencies} */
    static get $dependencies(): import("@ima/core").Dependencies<any>;
    /**
     * Initializes the style loader.
     *
     * @param {import('@ima/core').Window} window
     * @param {import('@ima/core').Dispatcher} dispatcher
     * @param {ResourceLoader} resourceLoader
     */
    constructor(window: import('@ima/core').Window, dispatcher: import('@ima/core').Dispatcher, resourceLoader: ResourceLoader);
    /**
     * IMA.js Window
     *
     * @type {import('@ima/core').Window}
     */
    _window: import('@ima/core').Window;
    /**
     * IMA.js Dispatcher
     *
     * @type {import('@ima/core').Dispatcher}
     */
    _dispatcher: import('@ima/core').Dispatcher;
    /**
     * General-purpose utility for loading resources.
     *
     * @type {ResourceLoader}
     */
    _resourceLoader: ResourceLoader;
    /**
     * Object of loaded styles.
     *
     * @type {Object<string, Promise<{url: string}>>}
     */
    _loadedStyles: {
        [x: string]: Promise<{
            url: string;
        }>;
    };
    /**
     * Load third party style to page.
     *
     * @param {string} url
     * @param {string=} [template]
     * @param {Object<string, Function | string | number>} [attributes]
     * @returns {Promise<{url: string}>}
     */
    load(url: string, template?: string | undefined, attributes?: {
        [x: string]: string | number | Function;
    } | undefined): Promise<{
        url: string;
    }>;
    /**
     * Creates a new style element and returns it.
     *
     * @param {boolean} isInlineStyle
     * @returns {HTMLLinkElement} The created style element.
     */
    _createStyleElement(isInlineStyle: boolean): HTMLLinkElement;
    /**
     * Handle on load event for style. Resolve load promise and fire LOADED
     * events.
     *
     * @param {string} url
     * @returns {{url: string}}
     */
    _handleOnLoad(url: string): {
        url: string;
    };
    /**
     * Handle on error event for style. Reject load promise and fire LOADED
     * events.
     *
     * @param {string} url
     * @throws Error
     */
    _handleOnError(url: string): void;
}
import { ResourceLoader } from '@ima/plugin-resource-loader';
